(*
This file is part of the first order theorem prover Darwin
Copyright (C) 2005
              The University of Iowa

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*)


(** global constants

    basically, this were determined by experiments
    and not considered important enough
    to be moved to the configuration options.
*)




(** {2 Exceptions} *)


(** the derivation is aborted because of a limitation of the implementation. *)
exception NO_SOLUTION of string




(** {2 Debug} *)

(** compile the (slow) debug version which performs additional consistency checks,
    i.e. each module may perform additional consistency checks. *)
val debug: bool



(** {2 Version} *)

(** the current system version, e.g. "Darwin 1.0" *)
val version: string


(** {2 Lemmas} *)

(** computation of lemmas from conflict sets ({!Lemma}). *)


(** ignore lemmas longer than this. *)
val max_lemma_size: int

(** instead of doing a full regression stop when more than
    this number of regressed literals have been found.
    the final lemma might still be very small,
    but unbounded regression is in general to expensive.
*)
val max_regression_size: int


(** instead of doing a full regression stop when the first uip (Unique Implication Point)
    has been found. *)
val first_uip: bool



(** {2 Jumping} *)

(** {!Jumping} through the search space. *)


(** a jump must at least skip over this many choice points. *)
val jumping_min_distance: int

(** Check after each [jump_check_every_splits] if a jump should be done
    (also based on the used time and the time limit). *)
val jumping_check_every_splits: int

(** for purposes of determining if a jump should be done
    the remaining time ration is assumed to be this fraction
    higher than it actually is (based on the given timeout and the used time). *)
val jumping_time_delta: float
